KVP

Struct KVP 

#[repr(C)]
pub struct KVP<TKey, TValue> { pub key: TKey, pub value: TValue, }
Represents the (key, value) pair, but with #[repr(C)] ABI.

Fields

key: TKeyvalue: TValue

Implementations

Source

impl<TKey, TValue> KVP<TKey, TValue>

pub const fn unpack(self) -> (TKey, TValue)

Unpacks the KVP and returns the key and value as a tuple.

pub const unsafe fn unpack_ptr(ptr: *mut Self) -> (*mut TKey, *mut TValue)

Unpacks the KVP from a raw pointer and returns the key and value as a tuple of raw pointers.

Safety

It is up to the caller to ensure that ptr is a valid, non-null pointer to a KVP.

pub const fn as_ref_kvp(&self) -> KVP<&TKey, &TValue>

Converts reference to KVP into KVP of references.

pub const fn as_mut_kvp(&mut self) -> KVP<&TKey, &mut TValue>

Converts mutable reference to KVP into KVP with key as a reference and value as a mutable reference.

pub const fn as_tuple(&self) -> (&TKey, &TValue)

Returns references to the key and value as a tuple.

pub const fn as_mut_tuple(&mut self) -> (&mut TKey, &mut TValue)

Returns mutable references to the key and value as a tuple.