#[repr(C)]pub struct KVP<TKey, TValue> {
pub key: TKey,
pub value: TValue,
}Expand description
Represents the (key, value) pair, but with #[repr(C)] ABI.
Fields
key: TKeyvalue: TValueImplementations
Sourceimpl<TKey, TValue> KVP<TKey, TValue>
impl<TKey, TValue> KVP<TKey, TValue>
Sourcepub const fn unpack(self) -> (TKey, TValue)
pub const fn unpack(self) -> (TKey, TValue)
Unpacks the KVP and returns the key and value as a tuple.
Sourcepub const unsafe fn unpack_ptr(ptr: *mut Self) -> (*mut TKey, *mut TValue)
pub const unsafe fn unpack_ptr(ptr: *mut Self) -> (*mut TKey, *mut TValue)
Sourcepub const fn as_ref_kvp(&self) -> KVP<&TKey, &TValue>
pub const fn as_ref_kvp(&self) -> KVP<&TKey, &TValue>
Sourcepub const fn as_mut_kvp(&mut self) -> KVP<&TKey, &mut TValue>
pub const fn as_mut_kvp(&mut self) -> KVP<&TKey, &mut TValue>
Sourcepub const fn as_tuple(&self) -> (&TKey, &TValue)
pub const fn as_tuple(&self) -> (&TKey, &TValue)
Returns references to the key and value as a tuple.
Sourcepub const fn as_mut_tuple(&mut self) -> (&mut TKey, &mut TValue)
pub const fn as_mut_tuple(&mut self) -> (&mut TKey, &mut TValue)
Returns mutable references to the key and value as a tuple.